MethodChannelImageProcessing class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

agePrediction({required Uint8List image}) → Future<String>
override
detectFaces({required Uint8List image}) → Future<String>
override
genderPrediction({required Uint8List image}) → Future<String>
override
initialize() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nsfwDetection({required Uint8List image}) → Future<String>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited