ImageProcessingPlatform class abstract

Implementers

Constructors

ImageProcessingPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

agePrediction({required Uint8List image}) → Future<String>
detectFaces({required Uint8List image}) → Future<String>
genderPrediction({required Uint8List image}) → Future<String>
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nsfwDetection({required Uint8List image}) → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ImageProcessingPlatform
getter/setter pair